@@ -1,13 +1,13 @@
 /* Test file for mpfr_custom_*
 
-Copyright 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
-Contributed by the Arenaire and Cacao projects, INRIA.
+Copyright 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+Contributed by the AriC and Caramel projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,14 +16,11 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
-#include <stdio.h>
 #include <stdlib.h>
-#include <limits.h>
-#include <string.h>
 
 #include "mpfr-test.h"
 
@@ -32,7 +29,7 @@ MA 02110-1301, USA. */
 
 long Buffer[BUFFER_SIZE];
 char *stack = (char *) Buffer;
-mp_prec_t p = PREC_TESTED;
+mpfr_prec_t p = PREC_TESTED;
 
 #define ALIGNED(s) (((s) + sizeof (long) - 1) / sizeof (long) * sizeof (long))
 
@@ -51,7 +48,7 @@ new_st (size_t s)
 
  /* Alloc a new mpfr_t on the main stack */
 static mpfr_ptr
-new_mpfr (mp_prec_t p)
+new_mpfr (mpfr_prec_t p)
 {
   mpfr_ptr x = (mpfr_ptr) new_st (sizeof (mpfr_t));
   void *mantissa = new_st (mpfr_custom_get_size (p));
@@ -64,7 +61,7 @@ new_mpfr (mp_prec_t p)
 static mpfr_ptr
 return_mpfr (mpfr_ptr x, char *old_stack)
 {
-  void *mantissa       = mpfr_custom_get_mantissa (x);
+  void *mantissa       = mpfr_custom_get_significand (x);
   size_t size_mantissa = mpfr_custom_get_size (mpfr_get_prec (x));
   mpfr_ptr newx;
 
@@ -85,9 +82,9 @@ test1 (void)
   org = stack;
   x = new_mpfr (p);
   y = new_mpfr (p);
-  mpfr_set_ui (x, 42, GMP_RNDN);
-  mpfr_set_ui (y, 17, GMP_RNDN);
-  mpfr_add (y, x, y, GMP_RNDN);
+  mpfr_set_ui (x, 42, MPFR_RNDN);
+  mpfr_set_ui (y, 17, MPFR_RNDN);
+  mpfr_add (y, x, y, MPFR_RNDN);
   y = return_mpfr (y, org);
   if (y != x || mpfr_cmp_ui (y, 59) != 0)
     {
@@ -119,7 +116,7 @@ dummy_set_si (long si)
   mpfr_t x;
   long * r = dummy_new ();
   (mpfr_custom_init_set) (x, 0, 0, p, &r[2]);
-  mpfr_set_si (x, si, GMP_RNDN);
+  mpfr_set_si (x, si, MPFR_RNDN);
   r[0] = mpfr_custom_get_kind (x);
   r[1] = mpfr_custom_get_exp (x);
   return r;
@@ -133,7 +130,7 @@ dummy_add (long *a, long *b)
   mpfr_custom_init_set (x, 0, 0, p, &r[2]);
   (mpfr_custom_init_set) (y, a[0], a[1], p, &a[2]);
   mpfr_custom_init_set (z, b[0], b[1], p, &b[2]);
-  mpfr_add (x, y, z, GMP_RNDN);
+  mpfr_add (x, y, z, MPFR_RNDN);
   r[0] = (mpfr_custom_get_kind) (x);
   r[1] = (mpfr_custom_get_exp) (x);
   return r;
@@ -161,13 +158,60 @@ test2 (void)
   (mpfr_custom_init_set) (x, c[0], c[1], p, &c[2]);
   if (c != a || mpfr_cmp_ui (x, 59) != 0)
     {
-      printf ("Compact (2) failed! c=%p a=%p\n", c, a);
+      printf ("Compact (2) failed! c=%p a=%p\n", (void *) c, (void *) a);
       mpfr_dump (x);
       exit (1);
     }
   stack = org;
 }
 
+static void
+test_nan_inf_zero (void)
+{
+  mpfr_ptr val;
+  int sign;
+  int kind;
+  char *org = stack;
+
+  val = new_mpfr (MPFR_PREC_MIN);
+
+  mpfr_set_nan (val);
+  kind = (mpfr_custom_get_kind) (val);
+  if (kind != MPFR_NAN_KIND)
+    {
+      printf ("mpfr_custom_get_kind error : ");
+      mpfr_dump (val);
+      printf (" is kind %d instead of %d\n", kind, MPFR_NAN_KIND);
+      exit (1);
+    }
+
+  sign = 1;
+  mpfr_set_inf (val, sign);
+  kind = (mpfr_custom_get_kind) (val);
+  if ((ABS (kind) != MPFR_INF_KIND) || (SIGN (kind) != SIGN (sign)))
+    {
+      printf ("mpfr_custom_get_kind error : ");
+      mpfr_dump (val);
+      printf (" is kind %d instead of %d\n", kind, MPFR_INF_KIND);
+      printf (" have sign %d instead of %d\n", SIGN (kind), SIGN (sign));
+      exit (1);
+    }
+
+  sign = -1;
+  mpfr_set_zero (val, sign);
+  kind = (mpfr_custom_get_kind) (val);
+  if ((ABS (kind) != MPFR_ZERO_KIND) || (SIGN (kind) != SIGN (sign)))
+    {
+      printf ("mpfr_custom_get_kind error : ");
+      mpfr_dump (val);
+      printf (" is kind %d instead of %d\n", kind, MPFR_ZERO_KIND);
+      printf (" have sign %d instead of %d\n", SIGN (kind), SIGN (sign));
+      exit (1);
+    }
+
+  stack = org;
+}
+
 int
 main (void)
 {
@@ -177,6 +221,7 @@ main (void)
     {
       test1 ();
       test2 ();
+      test_nan_inf_zero ();
     }
   tests_end_mpfr ();
   return 0;
